about summary refs log tree commit diff
path: root/sysdeps/ieee754/ldbl-128ibm/test-totalorderl-ldbl-128ibm.c
diff options
context:
space:
mode:
Diffstat (limited to 'sysdeps/ieee754/ldbl-128ibm/test-totalorderl-ldbl-128ibm.c')
-rw-r--r--sysdeps/ieee754/ldbl-128ibm/test-totalorderl-ldbl-128ibm.c11
1 files changed, 10 insertions, 1 deletions
diff --git a/sysdeps/ieee754/ldbl-128ibm/test-totalorderl-ldbl-128ibm.c b/sysdeps/ieee754/ldbl-128ibm/test-totalorderl-ldbl-128ibm.c
index 78b162c4fc..8e61a89f53 100644
--- a/sysdeps/ieee754/ldbl-128ibm/test-totalorderl-ldbl-128ibm.c
+++ b/sysdeps/ieee754/ldbl-128ibm/test-totalorderl-ldbl-128ibm.c
@@ -1,4 +1,4 @@
 /* Test totalorderl for ldbl-128ibm.
    Copyright (C) 2016 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
@@ -55,6 +55,15 @@ do_test (void)
 	  printf ("FAIL: test %zu\n", i);
 	  result = 1;
 	}
+      to1 = totalordermagl (ldx, ldy);
+      to2 = totalordermagl (ldy, ldx);
+      if (to1 && to2)
+	printf ("PASS: test %zu (totalordermagl)\n", i);
+      else
+	{
+	  printf ("FAIL: test %zu (totalordermagl)\n", i);
+	  result = 1;
+	}
     }
 
   return result;
@@ -1,4 +1,4 @@
-/* Test totalorderl for ldbl-128ibm.
+/* Test totalorderl and totalordermagl for ldbl-128ibm.
    Copyright (C) 2016 Free Software Foundation, Inc.
    This file is part of the GNU C Library.